Equisingular Calculations for Plane Curve Singularities
Abstract.
We present an algorithm which, given a deformation with section of a reduced plane curve singularity, computes equations for the equisingularity stratum (that is, the -constant stratum in characteristic ) in the parameter space of the deformation. The algorithm works for any, not necessarily reduced, parameter space and for algebroid curve singularities defined over an algebraically closed field of characteristic (or of characteristic ). It provides at the same time an algorithm for computing the equisingularity ideal of J. Wahl. The algorithms have been implemented in the computer algebra system Singular. We show them at work by considering two non-trivial examples. As the article is also meant for non-specialists in singularity theory, we include a short survey on new methods and results about equisingularity in characteristic .
Dedicated to the memory of Sevin Recillas
1. Introduction
Equisingular families of plane curve singularities, starting from Zariski’s pioneering ’Studies in Equisingularity I–III’ [Za], have been of constant interest ever since. Zariski intended to develop this concept aiming at a resolution of singularities where ’equisingular’ singularities should resolve simultaneously or are, in some sense, natural centres for blowing up. This approach was completely successful only in the case of families of plane curves11 1 Zariski originally considered equisingularity of a (germ of a) hypersurface along a subspace and a projection of such that is the image of a section of . If has codimension 1 then the fibres of are plane curve singularities. Zariski then considered the discriminant of the projection which is a hypersurface in (at least if is smooth) and thus equisingularity of along can be defined by induction on the codimension of in . where Zariski introduced several quite different, but equivalent, notions of equisingularity.
One of these notions was used by J. Wahl in his thesis to extend the concept of equisingularity to families over possibly non-reduced base spaces (see [Wa]). This enabled him to apply Schlessinger’s theory of deformations over Artinian rings and to define the equisingularity ideal wich describes the tangent space to the functor of equisingular deformations. Moreover, Wahl proved that the base space of the semiuniversal equisingular deformation of a reduced plane curve singularity is smooth. Wahl’s proof of this theorem, which is an important result in singularity theory, is quite complicated and uses several intermediate deformation functors, in particular deformations of the exceptional divisor of the embedded resolution of the singularity. Hence, he has to pass to deformations of global objects (the exceptional divisor) and not just of singularities.
The definition of equisingularity is algebraic and uses the resolution of singularities. But there is also a purely topological definition: two reduced plane curve singularities and in are equisingular iff they have the same embedded topological type, that is, there exist (arbitrary small) balls centred at and a homeomorphism of the triple onto for representatives of . As is homeomorphic to the cone over , the topological type of a reduced plane curve singularity is determined by the embedding of the link in , which consists of knots (circles embedded in where is the number of irreducible components of .
The topological type of each knot, which is an iterated torus knot, is determined by the pairs of ”turning numbers” for each iterated torus which itself are determined by and determine the sequence of Puiseux pairs of the corresponding branch. Moreover, the linking number of two knots coincides with the intersection number of the corresponding two branches. Hence, the topological type of is characterized by the Puiseux pairs of each branch and by the pairwise intersection numbers of different branches. This shows that the system of Puiseux pairs and the intersection numbers form a complete set of numerical invariants for the topological type or the equisingularity type of a plane curve singularity.
If we consider not just individual singularities but families, then the situation is even more satisfactory: the topological type is controlled by a single number, the Milnor number. Indeed, we have the following result due to Zariski [Za], Lê [Le, LR] and Teissier [Te1]. Let be a flat family of reduced plane curve singularities with section , then the following are equivalent (for a small representative of and the fibre over ):
- (1)
is equisingular along ,
- (2)
the topological type of is constant for ,
- (3)
the Puiseux pairs of the branches of and the pairwise intersection multiplicities of the branches are constant for ,
- (4)
the -invariant and the number of branches are constant for ,
- (5)
the Milnor number is constant for . 22 2 By a theorem of Lazzeri, if for then there is automatically a section such that is smooth and is constant.
Recall that for a reduced plane curve singularity defined by a (square-free) power series , the invariants , , and are defined as follows:
Here, and is the normalization of , that is, the integral closure of in its total ring of fractions. Furthermore, for each reduced plane curve singularity we have the relation (due to Milnor [Mi])
This result was complemented by Teissier [Te]33 3 The original proof of Teissier and Raynaud in [Te] has been clarified and extended to families of (projective) varieties in any dimension by Chiang-Hsieh and Lipman in [CL]., showing that for a normal base , the flat family admits a simultaneous normalization iff is constant.
The equivalence of (1) and (4) above shows the following: Let be the seminuniversal deformation of and let
be the -constant stratum of . Then coincides (as a set) with the equisingularity stratum of Wahl and, hence, is smooth.
Note that for higher dimensional isolated hypersurface singularities the -constant stratum is in general not smooth, cf. [Lu].
Despite the fact that the equisingularity stratum admits such a simple description, all attempts to find a general simple proof for its smoothness failed (except for irreducible germs, cf. [Te]).
One purpose of this paper is to report on a simple proof of Wahl’s theorem. The idea is to consider deformations of the parametrization
of , where is the normalization of . We define equisingular deformations of and prove that they are unobstructed. This is very easy to see, as they are (in certain coordinates) even linear. Then we show (by a direct argument on the tangent level) that equisingular deformations of and equisingular deformations of have isomorphic semiuniversal objects.
This proof has been known by the second author since about fifteen years and was communicated at several conferences. A preliminary preprint [GR1], joint with Sevin Recillas, has even been cited by some authors. Later on, these results have been extended to positive characteristic in a joint preprint of the authors [CGL] where, in addition, an algorithm to compute the equisingularity stratum was developed and used to prove one of the main results. However, meanwhile the theory of equisingularity in positive characteristic was further developed by the authors where the algorithm itself could be eliminated in the theoretical arguments [CGL1]. These results will be published elsewhere, but as we think that the algorithmic part of [CGL] should not be forgotten, we present it in this paper.
We start with a survey of the new methods and results about equisingularity in characteristic with a sketch of the proofs (for more details, we refer to [CGL1]). The main purpose of this paper is to describe an algorithm to compute the -constant stratum for an arbitrary deformation with section of a reduced plane curve singularity . More precisely, this algorithm computes an ideal with . As a corollary, we obtain an algorithm to compute the equisingularity ideal of Wahl. The algorithms work also in characteristic if is larger than the multiplicity of and we formulate them in this generality. They have been implemented in Singular [GPS] by A. Mindnich and the third author [LM].
2. The Fundamental Theorems
By Wahl, the equisingularity stratum in a versal family (with section ) is smooth. The idea of our proof for this fact is extremely simple. Consider the parametrization
of the -th branch of . Let, for ,
| (2.1) |
Now, we use the above characterization (3) for equisingularity, assuming that is the trivial section. Fixing the Puiseux pairs of is equivalent to the condition that no new characteristic term appears if we vary the . For each , this is an open condition on the coefficients . Moreover, it is easily checked that fixing the intersection multiplicity of and defines a linear condition among the and . Thus, if we consider (2.1) as a deformation of with replaced by coordinates , , then the equisingular deformations form a smooth subspace in the parameter space with coordinates . This family is easily seen to be versal. By general facts from deformation theory it follows then that each versal equisingular deformation of the parametrization has a smooth parameter space.
This argument works only for deformations over reduced base spaces . In particular, it does not work for infinitesimal deformations, that is, for deformations over
On the other hand, in order to use the full power of deformation theory we need infinitesimal deformations.
We continue this section by giving the required definitions for deformations of (the equation of) and of the parametrization of in the framework of deformation theory over arbitrary base spaces. These definitions are quite technical, which is, however, unavoidable.
Throughout the following, let be a reduced plane curve singularity, and let be a defining power series. We call , or just the (local) equation of . Deformations of (respectively embedded deformations of ) will also be called ’deformations of the equation’ (in contrast to ’deformations of the parametrization’, see Definition 2.3).
Definition 2.1.
A deformation (of the equation) of over a complex germ is a flat morphism of complex germs together with an isomorphism . It is denoted by .
A morphism from to a deformation consists of morphisms and making the obvious diagram commutative. If, additionally, a section of is given (that is, a morphism satisfying ), we speak about a deformation with section, denoted by .
A more explicit description is as follows: since each deformation of can be embedded, there is an isomorphism for some holomorphic map germ with
where is a closed subspace of some and are coordinates of . Moreover, under this isomorphism, coincides with the second projection. We also say that is isomorphic to the embedded deformation defined by . A given section can always be trivialized, that is, the ideal of can be mapped to under an isomorphism of embedded deformations.
The category of deformations (resp. of deformations with section) of is denoted by (resp. by ). The set of isomorphism classes of deformations with section (over the same base ) is denoted by (). Here, each isomorphism has to satisfy .
Definition 2.2.
Let be a reduced plane cure singularity given by and let be an (embedded) deformation with section of over given by . The deformation is called
-
equimultiple (along ) if where is the multiplicity of (if is the trivial section, this means that ).
-
equisingular (along ) if it is equimultiple along and if, after blowing up , there exist sections through the infinitely near points in the first neighbourhood of such that the respective reduced total transforms of are equisingular along these sections.
Further, a deformation of a nodal singularity (with local equation ) is called equisingular if it is equimultiple. (The same applies to a deformation of a smooth germ.)
Thus, equisingularity of a deformation with section of is defined by induction on the number of blowing ups needed to get a reduced total transform of which consists of nodal singularities only. A deformation without section is called equisingular, if it is equisingular along some section.
Let , resp. , denote the category of equisingular deformations of as a full subcategory of , resp. of . The set of isomorphism classes of equisingular deformations with section of over is denoted by and
is called the functor of equisingular deformations with sections. Similarly, we define , the (abstract) equisingular deformation functor.
Next, we define deformations of the parametrization. We fix a commutative diagram of complex (multi-) germs
where is a reduced plane curve singularity (with a fixed embedding ), is its normalization, and is its parametrization. If is the decomposition of into irreducible components, then is a multigerm, and maps surjectively onto . In particular, by restriction, induces the normalization of the component .
Since and are smooth (multi-)germs, each deformation of these germs is trivial.
Definition 2.3.
(1) A deformation of the parametrization over a germ (with compatible sections) is given by the left (Cartesian) part of the following diagram
| (2.2) |
where is flat. We have , and there are isomorphisms , such that the obvious diagram (with the projection) commutes.
Systems of compatible sections consist of disjoint sections of (where denotes the restriction of ) and a section of such that , . Morphisms of such deformations are given by morphisms of the diagram (2.2).
(2) The category of deformations of the parametrization over (without sections) is denoted by . Its objects are denoted by or just by . The corresponding category of deformations of with compatible sections is denoted by . Its objects are denoted by . The respective sets of isomorphism classes of deformations are denoted by and .
(3) denotes the corresponding vector space of (first order) infinitesimal deformations of the parametrization with section.
The following theorem shows that deformations of the parametrization induce (unique) deformations of the equation:
Theorem 2.4.
Each deformation of the parametrization of the reduced curve singularity induces a deformation of the equation which is unique up to isomorphism and which is given as follows: the Fitting ideal of , generated by the maximal minors of a presentation matrix of as -module, is a principal ideal which coincides with the kernel of the induced morphism of rings . If is a generator for this ideal, then defines an embedded deformation of .
In the same way, a deformation with compatible sections induces a deformation with section of the equation.
The proof of this theorem uses the local criterion of flatness from local algebra and proceeds by reduction to the special fibre, that is, to the case that is the reduced point.
A deformation of the parametrization (as in the right-hand part of the diagram (2.2)) is given by ,
where , , , and where is the given parametrization of . We may assume that the compatible (multi-)sections and are trivial, that is, , .
Definition 2.5.
Let be a deformation of the parametrization as above (with trivial sections ).
- (1)
is called equimultiple (along ) if
- (2)
is called equisingular if it is equimultiple and if for each infinitely near point of on the strict transform of (after finitely many blowing ups) the deformation can be lifted to an equimultiple deformation of the parametrization of the strict transform in a compatible way (see [GLS] for a detailed description of the compatibility condition).
We denote by the category of equisingular deformations of the parametrization , and by the corresponding functor of isomorphism classes. Moreover, we introduce
the tangent space to this functor.
Note that , , and we set
Lemma 2.6.
With the above notations, there is an isomorphism of vector spaces,
where denotes the set of all elements
such that defines an equisingular deformation of over along the trivial sections.
We call the equisingularity module of the parametrization of . It is an -submodule of . Here, denotes the module of -derivations .
The following theorem shows that is a “linear” subfunctor of . As such, it is already completely determined by its tangent space. We use the notation
Theorem 2.7.
With the above notations, the following holds:
(1) Let be a deformation of with trivial sections over , where with
. Then is equisingular iff for all .
(2) Let be an equisingular deformation of with trivial sections over , where for some . Then is a versal (respectively semiuniversal) object of iff the derivations
represent a system of generators (respectively a basis) of the complex vector space .
(3) Let , , represent a basis (respectively a system of generators) of . Moreover, let be the deformation of over given by
, and let be the trivial sections. Then is a semiuniversal (respectively versal) equisingular deformation of over . In particular, equisingular deformations of the parametrization are unobstructed, and the semiuniversal deformation has a smooth base space of dimension .
In the proof we make a power series ”Ansatz” and then we explicitly verify the condition of versality in the spirit of Schlessinger.
To compute a semiuniversal equisingular deformation of , we only need to compute a basis of by Theorem 2.7. Moreover, if all branches of have different tangents, then decomposes as
where is the parametrization of the -th branch of . In general, can be computed following the lines of the proof of Theorem 2.7.
Examples 2.8.
(1) Consider the parametrization of an -singularity. A basis for the module of equimultiple deformations is given by . Blowing up the trivial section of the deformation of given by , , we get
which is equimultiple along the trivial section iff . Blowing up once more, we get the necessary condition for equisingularity. Hence, as expected for a simple singularity (each equisingular deformation of a simple singularity is known to be trivial).
(2) For the parametrization of an -singularity, a basis for is given by (resp. by ). Blowing up the trivial section, only (resp. ) survives for an equimultiple deformation. It also survives in further blowing ups. Hence, , (resp. , ) is a semiuniversal equisingular deformation of .
The following theorem relates deformations of the parametrization to the -constant stratum in the semiuniversal deformation of the equation. It is an improvement of the results by Teissier and Raynaud, by Chian-Hsieh and Lipman, and by Diaz and Harris [DH].
Theorem 2.9.
With the above notations, the following holds:
(1) Let be a deformation of , and let be the induced deformation of the equation of . Then is constant for near .44 4 For germs , etc., , etc. always denote sufficiently small representatives.
(2) Let be the semiuniversal deformation of the equation of , and let be the -constant stratum of . Then:
- (a)
The semiuniversal deformation of the parametrization of is induced from via a morphism such that
- •
and
- •
is the normalization of .
- •
- (b)
has a smooth normalization and .
- (c)
is smooth iff all branches of are smooth.
The proof of this theorem uses the results of [Te1] and [CL] mentioned in the introduction, the fact that for every plane curve singularity there is a -constant deformation such that the general fibre has simple nodes, and an exact sequence relating first order deformations of the equation and of the parametrization.
When passing to equisingular deformations of the parametrization, we have to consider deformations with compatible sections. It can be shown that the sections are unique (in characteristic ). Then, a refinement of the above arguments for equisingular deformations proves the following theorem:
Theorem 2.10.
Let be the semiuniversal equisingular deformation of the parametrization of , and let be the inducing morphism to the base space of the semiuniversal deformation of the equation. Then is an isomorphism onto the -constant stratum . In particular, is smooth.
3. The Algorithms
The idea of the following algorithm to compute the equisingularity stratum of a family of plane curve singularities with trivial section was developed in our joint preprint [CGL]. In that paper we introduced the notion of equisingularity for plane algebroid curves given by a formal power series , where is an algebraically closed field of any characteristic.
The definitions of the previous section remain true, mutatis mutandis, for algebroid curves. However, we cannot use the geometric language. Instead of morphisms between complex space germs, we have to consider morphisms (in the opposite direction) between the corresponding local analytic algebras. Points close to have to be replaced by generic points of , etc. For , it does not make any difference whether we consider convergent or formal power series. The reason for considering convergent power series in the previous section is that the concept of equisingularity can be best explained in a geometric context and that a great deal of the motivaton comes from topology.
However, there is an important difference between the case of characteristic and the case of positive characteristic. As shown in [CGL], in positive characterestic we have two equally important notions of equisingularity, namely weak and strong equisingularity which coincide in characteristic . The definitions for equisingularity given in Section 2 (appropriately formulated on the level of analytic rings), either for the equation or for the parametrization, refer to the notion of strong equisingularity (which we continue to call equisingularity).
The theorems of the previous section remain true for algebraically closed fields of characteristic as long as does not divide the multiplicity of any factor of (in particular, for each algebraically closed field of characteristic ). This result, proved in [CGL1] has the important computational consequence that for a power series with integer coefficients we can compute characteristic numerical invariants like , and the Puiseux pairs55 5 Note that, in positive characteristic, the Milnor number as defined on Page 1 depends on the equation and not only on the ideal . Instead, we define the Milnor number in characteristic as .in characteristic by computing them modulo a prime number , where is bigger than the multiplicity of . This is the reason why we work in this section with analytic local rings over a field of possibly positive characteristic.
In [CGL1], we treat the case of arbitrary characteristic. Here, we treat only (strong) equisingularity and assume, that the characteristic of does not divide the multiplicity of any branch of .
Since the Puiseux expansion is in general not available in positive characteristic, we work with the Hamburger-Noether expansion instead (cf. [Ca, Ca1]).
We fix the notations. denotes an algebraically closed field of characteristic . All rings in this section will be Noetherian complete local -algebras with maximal ideal such that . The category of these algebras is denoted by . Further, we denote by the two-dimensional -algebra with . Let be a reduced algebroid plane curve singularity over , defined by the (square-free) power series .
denotes the complete local ring of . Let be an irreducible factorization of . The rings
are the complete local rings of the branches of . The normalization of is the integral closure of in its total ring of fractions . It is the direct sum of the normalizations of , , hence a semilocal ring. Each is a discrete valuation ring, and we can choose uniformizing parameters such that . After fixing the parameters , we identify with and get
The normalization map is induced by a mapping , , which is called a parametrization of .
The following definition is to local analytic -algebras what Definition 2.3 is to analytic germs:
Definition 3.1.
A deformation with sections of the parametrization of over is a commutative diagram with Cartesian squares
with , where , , and are Noetherian complete local -algebras which are flat over . is a section of , and is a section of , . We denote such a deformation by .
A morphism from to another deformation over is then given by morphisms , and in such that the resulting diagram commutes. The category of such deformations is denoted by . If we consider only deformations over a fixed base , we obtain the (non-full) subcategory with morphisms being the identity on . is a fibred gruppoid over , that is, each morphism in is an isomorphism.
Since and the are regular local rings, each deformation of and of is trivial. That is, there are isomorphisms and over , mapping the sections and to the trivial sections. Hence, each object in is isomorphic to a diagram of the form
| (3.1) |
where is the identity on and , are the trivial sections (that is, the canonical epimorphisms mod , respectively mod ). Here, is given by , where is determined by
, such that , mod .
We write for the set of isomorphism classes of objects in , and we denote by the corresponding deformation functor. Moreover, we denote by the vector space of (first order) infinitesimal deformations of the parametrization of .
Remark 3.2.
Replacing in the above definition the parametrization by the normalization , we get the functor of deformations of the normalization. The version of Theorem 2.4 for local -algebras implies that this functor is naturally equivalent to . ∎
It is now straightforward to translate the definition of equisingular deformations of the parametrization from the geometric to the algebraic context. We leave this to the reader. For the algorithms, it is only important to know that a deformation (3.1) is equisingular iff (up to a reparametrization) it is given by a Hamburger-Noether deformation of over , which we introduce next (see Proposition 3.8 below).
Definition 3.3.
A Hamburger-Noether expansion (HNE) over is a finite system of equations in the variables of type
where is a nonnegative integer, the coefficients are elements of , the are positive integers, and we assume that the first nonzero coefficient in each row, except in the first one, is a unit in . Finally, if , then the power series on the right-hand side of the last equation in is nonzero. We call the length of .
Given a Hamburger Noether expansion over , we define the residual HNE to be the Hamburger-Noether expansion over obtained by substituting the coefficients by the respective residual classes .
Remark 3.4.
Let be as above, and let
be the partition of the index set such that (resp. ) consists of those indices for which the line is transversal (resp. tangent) to the branch . Then associated with each branch one has a unique Hamburger-Noether expansion over of some length such that, setting , if and , if , and , and making successive back-substitutions in , we obtain power series defining a parametrization of the branch . The uniqueness comes from the fact that, since a transversal parameter is fixed, the data of the Hamburger-Noether expansion collect the information about the coordinates of the successive infinitely near points on the branch in appropriate coordinate systems (see [Ca, Ch. II]). Further, the expansions are pairwise different in and in , and for one has, in addition to the defining properties for a Hamburger-Noether expansion, that . ∎
Definition 3.5.
A deformation of the Hamburger-Noether expansion of over (or simply a Hamburger-Noether deformation of over ) is a system of Hamburger-Noether expansions , , over ,
such that, for each the following holds:
- (HN1):
-
, the Hamburger-Noether expansion for (over ).
- (HN2):
-
If and are either both in or both in and if denotes the smallest integer such that , then either the multiplicity of exceeds the minimum of , or the coefficient of its term of smallest degree is a unit in .
Example 3.6.
Let and . Then the system
is a Hamburger-Noether deformation of over . If we replace the last equation in by , then is still a Hamburger-Noether expansion over , but do not define a Hamburger-Noether deformation of over (the condition (HN2) is not satisfied).
Remark 3.7.
By setting
and , and by making successive back-substitutions, we obtain power series , , satisfying . These define a deformation of the parametrization
, , of which is induced by the system of Hamburger-Noether expansions for .
For instance, in the above example, we get the deformation of the parametrization given by
∎
Proposition 3.8.
The deformation of the parametrization associated to a Hamburger-Noether deformation of over is equisingular (along the trivial section ). This association is functorial in . Conversely, every equisingular deformation of the parametrization with trivial section is given, up to a re-parametrization, by a Hamburger-Noether deformation.
The proof of this proposition (as given in [CGL]) provides an algorithm for finding the Hamburger-Noether deformation of associated to an equisingular deformation of the parametrization. This leads to the following algorithm which allows one to decide whether a given deformation of the parametrization is equisingular:
Algorithm 1 (Check equisingularity).
- Input:
, , defining a deformation of the parametrization of a reduced plane curve singularity over a complete local -algebra .
- Output:
if the deformation is equisingular along the trivial section, otherwise.
Step 1. (Initialization)
- •
For each , set
- •
Set , .
Step 2. If for some the condition
is not fulfilled then Return(0).
Step 3. (Compute the Hamburger-Noether expansions )
For each do the following:
- •
Set , if , and , if .
- •
If , then the Hamburger-Noether expansion has length and the coefficients are obtained by expanding as a power series in .
- •
Set , .
- •
While do the following:
- –
While , set , define to be the residue modulo of , and set
- –
If the leading coefficient of is not a unit in , then Return(0).
- –
Set , , and .
- –
- •
The Hamburger-Noether expansion has length and the coefficients in its last row are obtained by expanding as a power series in .
Step 4. (Check condition (HN2) for a Hamburger-Noether expansion)
For each , , set . If the condition (HN2) is satisfied then Return(1), otherwise Return(0). ∎
Remark 3.9.
Algorithm 1 can be extended in an obvious way to an algorithm which computes for an arbitrary deformation with trivial section of the parametrization of over an ideal such that the induced deformation over is equisingular and, if is any other ideal with this property, then . If we apply this algorithm to the deformation of the parametrization given by
over the Artinian -algebra , , where the
represent a -basis of , then the conditions obtained are -linear equations in the . Solving the system of these linear equations and restricting the family to the corresponding subspaces, we get a family
where is a subset of , and where the are -linear combinations of the . Then the , , generate a linear subspace of which is necessarily equal to . This follows, since , since the algorithm commutes with base change (fixing the ), and since is unique as a subspace of . In this way, we obtain an effective way to compute and, hence, to compute the semiuniversal equisingular deformation of (see Theorem 2.7). ∎
Proposition 3.8, together with the relation between (equisingular) deformations of the parametrization and (equisingular) deformations of the equation discussed in Theorem 2.4 and Theorem 2.10 leads to the following algorithm for computing the equisingularity stratum in the base space of a deformation with trivial section of a reduced plane curve singularity (given by , ). That is, the algorithm computes an ideal such that the induced deformation over is equisingular along the trivial section and is minimal in the sense that, for each ideal such that the induced deformation over is equisingular along the trivial section, we have .
Algorithm 2 (Equisingularity stratum).
- Input:
, , defining a deformation over the local -algebra of the reduced plane curve singularity with equation .
- Assume:
Either or .
- Output:
A set of generators for .
Step 1. (Initialization)
- •
Compute the system of Hamburger-Noether expansions for .66 6 This may be done by applying the algorithm of Rybowicz [Ry] (extending the algorithm in [Ca] to the reducible case). An implementation of this algorithm is provided by the Singular library hnoether.lib written by M. Lamm. In particular, determine the number of branches of .
- •
Set , .
- •
For each , set .
Step 2. (Check equimultiplicity)
- •
If then Return .
- •
Let then set
- •
Let the -jet of decompose as
where the factor corresponds to branches of , say , while each factor , , corresponds to branches, say (this information can easily be read from the Hamburger-Noether expansions ). Then we introduce new variables and impose the following condition on the -jet (in ) of :
(3.2) with , . Set , and add the conditions obtained by comparing the () coefficients of , , on both sides of the equation to . Note that is now a subset of .
Step 3. (1st blowing up)
If then set , . Moreover, set
.
Step 4. (Check equimultiplicity after successive blowing up)
While , choose any and do the following:
- •
Set , and .
- •
If then the -jet of necessarily equals , and we impose the following condition on the -jet of :
(3.3) Set , and add the conditions obtained by comparing the coefficients of , , on both sides of the equation (3.3) to . Finally, set , reduce by the linear elements of , and set
- •
Otherwise, redefine such that
where the factor corresponds to branches, say , while each factor , , corresponds to branches, say (again, this information can easily be read from ). We introduce variables and impose the following condition on the -jet of :
(3.4) with , . Set , and add the conditions obtained by comparing the coefficients of , , on both sides of (3.4) to . Reduce by the linear elements of .
- •
(Blowing up)
For , set
Moreover, if then set ,
and .
- •
If and then .
Step 5. (Eliminate auxiliary variables)
- •
Set .
- •
- •
(Hensel lifting) For the remaining do the following: if appears only in one element of , remove this element from . Otherwise, compute the unique Hensel lifting of the factorization of in the defining equation (3.2), resp. (3.4), for :
where , and . If the auxiliary variable was introduced in the factor with constant term , then replace by in all terms of elements of .88 8 Note that, if the Hensel lifting for the factorization of in the defining equation (3.2) has to be computed, and if there is one factor of with tangent and one with tangent , apply a coordinate change of type , , first.
Step 6. Return().
The proof of correctness for this algorithm is based on results of [Ca1] and the following two easy lemmas (see the end of this section for proofs):
Lemma 3.10 (Uniqueness of Hensel lifting).
Let be a complete local -algebra, and let be a monic polynomial satisfying
Then there exists a unique Hensel lifting of the factorization,
Lemma 3.11.
Let be a local -algebra, and suppose that the characteristic of does not divide the positive integer . Then, for any , the following are equivalent:
- (1)
,
- (2)
.
As mentioned before, the algorithm is based on the relation between equisingular deformations of the equation (along the trivial section) and Hamburger-Noether deformations. It is not difficult to see that the terms on the right-hand side of (3.2), respectively (3.4), correspond precisely to the ‘free’ coefficients of the Hamburger-Noether expansions , respecting the condition (HN2). The condition that the first nonzero coefficient in each row (except in the first one) has to be a unit is reflected in the algorithm by introducing . On the other hand, the left-hand side of (3.2), resp. (3.4), is the deformation of obtained after performing the respective blowing-ups (with indeterminates ). The proof of [Ca1, Thm. 1.3] shows that defines an equisingular deformation of over along the trivial section iff it defines an equimultiple deformation along (Step 2) and there exist , , such that the conditions (3.2), (3.3) and (3.4) are satisfied modulo .
Lemma 3.10 implies that the factor on the right-hand side of (3.2), resp. (3.4), is uniquely determined (as a factor of the Hensel lifting of the factorization of ). Lemma 3.11, together with our assumption on the characteristic of , gives that is uniquely determined (as described in Step 5 of the algorithm). Note that the integer appearing in the Hensel lifting step of the algorithm is the sum of multiplicities of the strict transforms of some branches of , hence and our assumption implies that is not divisible by the characteristic of . ∎
Remark 3.12 (Working with polynomial data).
In practice, we want (and can) apply Algorithm 2 only to the case where the curve and its deformation are given by polynomials. Thus, let for some ideal , and let . Applying Algorithm 2 to does not necessarily lead to polynomial (representatives of) generators for . This is caused by the Hensel lifting in Step 5. However, under certain circumstances the Hensel lifting may be avoided, replacing Step 5 by a Gröbner basis computation99 9 A Singular implementation of the resulting algorithm is accessible via the command esStratum provided by the library equising.lib [LM].:
Step 5’. (Eliminate )
-
Let be the ideal of generated by . Compute a set of polynomial generators for the elimination ideal
This can be done by computing a Gröbner basis for with respect to a product ordering on , where is global and is local. Set .
Let, for instance, define an irreducible plane curve singularity. Then all appearing polynomials are unitangential. Hence, (3.4) reads either , or
If the -jet of is then the latter gives the equations
| (3.5) |
In particular, the substitution of by in the elements of is also performed by the Gröbner basis algorithm (multiplying the resulting elements by appropriate units of the local ring ).
Similarly, if we consider a deformation over an Artinian base space, say , then we may again replace Step 5 in the algorithm by the above Step 5’. In this case, we additionally have to add to all monomials in of degree .
In particular, this allows us to compute a set of generators for Wahl’s equisingularity ideal [Wa] working with polynomial data only:
Algorithm 3 (Equisingularity ideal).
- Input:
, defining a reduced plane curve singularity .
- Assume:
Either or .
- Output:
A set of generators for the equisingularity ideal
Step 1. (Initialization)
- •
Compute a (monomial) -basis for the -algebra (see [GP]).
- •
Compute the system of Hamburger-Noether expansions for . In particular, read the number of branches of and the number of free infinitely near points of corresponding to non-nodal singularities of the reduced total transform of .
- •
Introduce new variables and set
.
- •
For each , set .
As in Algorithm 2, applied to and the ring , . (Instead of introducing new variables , reuse the variables introduced in Step 1).
Step 5’. As above.
Step 6. Compute a reduced normal form for w.r.t. and set
Step 7. Return().
A Singular implementation of this algorithm is accessible via the esIdeal command provided by equising.lib [LM].
Finally, also for reducible plane curve singularities, we may replace the Hensel lifting step by Step 5’. Then the algorithm computes defining equations for the equisingularity (-constant) stratum as an algebraic subset of (but not necessarily with the correct scheme-theoretic structure imposed by deformation theory). Indeed, the computation in Step 5’ yields equations for the image of under the projection
where denotes the germ of at the origin with respect to the Zariski topology (see [GP]). Now, intersects the Zariski closure of the fibre in only at the origin and at finitely many points which correspond to a permutation of the factors in (3.3), resp. in (3.4) (that is, is replaced by ) . The uniqueness of the Hensel lifting implies that the image of the analytic germ of at under coincides with the image of the analytic germ of at . Thus, the analytic germ of the image computed by eliminating coincides with the image under of the analytic germ of at the origin. ∎
Proof of Lemma 3.10. The existence of the Hensel lifting follows since is Henselian (see, e.g., [GR, § I.5, Satz 6]). It remains to prove the uniqueness. Consider
where . Hence, , while is a Weierstraß polynomial in (of degree ). Assuming that there exist two such decompositions , we would have , where has degree at most . But
whence contains a term (). Setting , and choosing minimally such that , it is obvious that the product (with minimal) would have degree at least , and could not be cancelled by any other term of . It follows that , hence the uniqueness. ∎
Proof of Lemma 3.11. In characteristic zero, the equivalence is obvious. Thus, let and write , with a non-negative integer, such that does not divide . Then the equality implies
Hence, if (that is, if does not divide ) we get . The proof shows that the equivalence in Lemma 3.11 holds in arbitrary characteristic if the -algebra is reduced. ∎
Remark 3.13.
(1) In concrete calculations, we have to distinguish carefully between deformations which are equisingular along a given section and those which are abstractly equisingular, that is, equisingular along some section. The corresponding deformation functors are and as introduced in Definition 2.2.
(2) Algorithm 2 computes the ideal of the maximal stratum in the parameter space such that the restriction of the family defined by is equisingular along the trivial section. If a family with non-trivial section is given, then one has to trivialize this section first and then to apply Algorithm 2 in order to compute the stratum such that the family is equisingular along . For instance, the family given by is equisingular along the section , while Algorithm 2 computes , which means that is the maximal stratum of equisingularity along the trivial section .
(3) Let and let define the semiuniversal deformation with (trivial) section of the reduced plane curve singularity given by , that is, , where represents a -basis of . Then the ideal as computed by Algorithm 2 defines the stratum of -constancy along the trivial section of the family defined by . This stratum is isomorphic to the -constant stratum of the semiuniversal deformation of (without section) given by , where represents a -basis of the Tjurina algebra (this follows from Theorem 2.10).
Note that the ideal contains more information than just about the -constant stratum. It gives the semiuniversal equisingular family such that every fibre has a singularity of Milnor number at the origin.
(4) The isomorphism between the -constant strata in (3) is unique on the tangent level and the corresponding tangent map
is induced by the inclusion . Here,
which can be computed along the lines of Algorithm 3, replacing the definition of in Step 6 by
The Singular procedure esIdeal returns both, and .
4. Examples
In the first example, we compute defining equations for the stratum of -constancy along the trivial section for a deformation of a reduced plane curve singularity (with two singular branches) over a smooth base. We proceed along the lines of Algorithm 2, slightly modifying and anticipating Step 5 (resp. Step 5’):
Example 4.1.
Let and consider the deformation of the Newton degenerate plane curve singularity over , , given by
In the first step of the algorithm, we compute the system of Hamburger-Noether expansions for (developing each final row up to a sufficiently high order as needed for computing the system of multiplicity sequences):
Since all deformation terms lie above (or on) the Newton boundary, the equimultiplicity condition in Step 2 of the algorithm does not lead to a new element of . Further, we impose a factorization , which is only possible for (that is, ). We apply the formal blowing-up (Step 3)
and set . We obtain which has order . Hence, in (3.4), we impose the condition , which is obviously satisfied for . We set
and . Hence, in the following two turns of the loop in Step 4, we impose the condition and perform then the formal blowing-up . Note that both turns do not lead to new elements of . After the second turn, we have
modulo . In the next turn, we impose the condition
hence , and we obtain the equations
which imply , that is, in Step 5 (resp. 5’), and will be added to (we anticipate this here and set ). We apply the formal blowing-up
modulo . The imposed condition reads now
hence , , and . That is, partly anticipating Step 5 or 5’, we set . We apply the formal blowing-up
and impose the condition
Hence, , , and we obtain the equations (again partly anticipating Step 5 or 5’):
which are added to . Now, we set
both being of order , whence , and we may assume to enter Step 5 with
Since appears in exactly one of the elements of , we simply remove this element from . Then appears in only one element, too. So, we also remove this element and there is no need to apply a Hensel lifting step, that is, to compute the power series expansion of . The same result is obtained by applying the elimination procedure of Step 5’:
Since the deformation terms of , together with the terms below the Newton boundary, generate the Tjurina algebra , we can, in particular, read off the equisingularity ideal of :
∎
The second example shows the computation of in the case of a Newton degenerate plane curve singularity with smooth branches:
Example 4.2.
Let . We start with the versal deformation with trivial section of , given by , ,
(here, we displayed only the terms of degree at least ). The system of Hamburger-Noether expansions for is
where . From these expansions, we read that there are free infinitely near points of corresponding to non-nodal singularities of the reduced total transform of . We initialize as
The equimultiplicity condition of Step 2 implies that the 34 non-displayed terms of must be zero, that is, we set . In Step 5, we impose now a decomposition
which modulo leads to 8 new linear relations:
We set
all of them being of multiplicity as power series in . Choosing, for instance, (that is, considering ), we impose the new condition (modulo )
which leads to the conditions
Proceeding in the same way with the other possible choices , we obtain three more (linearly independent) conditions for , and conditions of type , some linear polynomial in , . Since the eight polynomials obtained after the next formal blowing-ups are all of order , we reach Step 5’ and compute
Hence, the base of the semiuniversal equisingular deformation of has dimension , and
∎
Remark 4.3.
The correctness of the computed equations for the stratum of -constancy (resp. equisingularity) can be checked by choosing a random point satisfying the equations and computing the system of Hamburger-Noether expansions for the evaluation of at . From the system of Hamburger-Noether expansions, we can read a complete set of numerical invariants of the equisingularity type (such as the Puiseux pairs and the intersection numbers) which have to coincide with the respective invariants of . In characteristic , it suffices to compare the two Milnor numbers. We use Singular to compute the -constant stratum in our second example:
LIB "equising.lib"; //loads deform.lib, sing.lib, too
ring R = 0, (x,y), ds;
poly f = (y4-x4)^2 - x10;
ideal J = f, maxideal(1)*jacob(f);
ideal KbJ = kbase(std(J));
int N = size(KbJ);
ring Px = 0, (a(1..N),x,y), ls;
matrix A[N][1] = a(1..N);
poly F = imap(R,f)+(matrix(imap(R,KbJ))*A)[1,1];
list M = esStratum(F); //compute the stratum of equisingularity
//along the trivial section
def ESSring = M[1]; setring ESSring;
option(redSB);
ES = std(ES);
size(ES); //number of equations for ES stratum
//-> 42
Inspecting the elements of ES, we see that of the deformation parameters must vanish. Additionally, there are two non-linear equations, showing that the equisingularity (-constant) stratum is smooth (of dimension ) but not linear:
ES[1]; //-> 8*A(1)+8*A(22)+A(1)^3 ES[34]; //-> 8*A(40)-A(1)^2+A(1)*A(22)
We reduce F by ES and evaluate the result at a random point satisfying the above two non-linear conditions:
poly F = reduce(imap(Px,F),ES); //A(1),A(22) both appear in F
poly g = subst(F, A(22), -A(1)-(1/8)*A(1)^3);
for (int ii=1; ii<=44; ii++){ g = subst(g,A(ii),random(1,100)); }
setring R;
milnor(f); //Milnor number of f
//-> 57
milnor(imap(ESSring,g)); //Milnor number of g
//-> 57
∎
References
- [Ca] Campillo, A.: Algebroid curves in positive characteristic. SLN 813, Springer-Verlag (1980).
- [Ca1] Campillo, A.: Hamburger-Noether expansions over rings. Trans. Amer. Math. Soc. 279, No. 1 (1983).
- [CGL] Campillo, A.; Greuel, G.-M.; Lossen, C.: Equisingular deformations in positive characteristic. Preprint 2003.
- [CGL1] Campillo, A.; Greuel, G.-M.; Lossen, C.: Equisingular deformations in arbitrary characteristic. In preparation.
- [CL] Chiang-Hsieh, H-J.: Lipman, J:: A numerical criterion for simultaneous normalization. arXiv:math.AG/0408394 (2004).
- [DH] Diaz, S.; Harris, J.: Ideals associated to deformations of singular plane curves. Trans. Amer. Math. Soc. 309, 433–468 (1988).
- [GLS] Greuel, G.-M.; Lossen, C.; Shustin, E.: Introduction to singularities and deformations. To appear at Springer-Verlag (2006).
- [GP] Greuel, G.-M.; Pfister, G.: A Singular introduction to commutative algebra. Springer (2002).
- [GPS] Greuel, G.-M.; Pfister, G.; Schönemann, H.: Singular 3.0.0. A Computer Algebra System for Polynomial Computations. ZCA, University of Kaiserslautern (2005). http://www.singular.uni-kl.de.
- [GR] Grauert, H.; Remmert, R.: Analytische Stellenalgebren. Springer (1971).
- [GR1] Greuel, G.-M.; Recillas, S.: On deformations of maps and curve singularities. Preprint University of Kaiserslautern (2000).
- [Le] Lê, D.T.: Sur un critère d’équisingularité. C.R.A.S. Paris, 222, 138–140 (1971).
- [LM] Lossen, C.; Mindnich, A.: equising.lib. A Singular library for computing the equisingular stratum of a family of plane curves (2003).
- [LR] Lê, D.T.; Ramanuyam, C.P.: The invariance of Milnor’s number implies the invariance of the topological type. Amer. Journ. Math. 98, 67–78 (1976).
- [Lu] Luengo, I.: The -constant stratum is not smooth. Invent. Math. 90, 139–152 (1987).
- [Mi] Milnor, J.: Singular points of complex hypersurfaces. Princeton Univ. Press (1968).
- [Ry] Rybowicz, M.: Sur le calcul des places et des anneaux d’entiers d’un corps de fonctions algébriques. Thèse d’état, Univ. de Limoges (1990).
- [Te] Teissier, B.: The hunting of invariants in the geometry of discriminants. In P. Holm, Real and Complex Singularities, Oslo 1976, Northholland (1978).
- [Te1] Teissier, B.: Résolution simultanée I, II. In: Seminaire Demazure-Pinkham-Teissier 1976/1977, SLN 777, Springer (1980).
- [Wa] Wahl, J.: Equisingular deformations of plane algebroid curves. Trans. Amer. Math. Soc. 193, 143–170 (1974).
- [Za] Zariski, O.: Studies in equisingularity I–III. Amer. Journ. Math. 87, 507–536 and 972–1006 (1965), resp. Amer. Journ. Math. 90, 961–1023 (1968).